<?php

declare(strict_types=1);

namespace Pinpoint\TaxSwitch\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;
use Pinpoint\TaxSwitch\Api\ConfigHelperInterface;

/**
 * This class is responsible for getting tax switch configuration
 */
class Config extends AbstractHelper implements ConfigHelperInterface
{
    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    private $storeManager;

    /**
     * @param \Magento\Framework\App\Helper\Context      $context
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager
    ) {
        $this->storeManager = $storeManager;
        parent::__construct($context);
    }

    /**
     * @inheritDoc
     */
    public function isEnabled($scopeType = null, $scopeCode = null): bool
    {
        if ($scopeType === null) {
            $scopeType = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        }

        if ($scopeCode === null) {
            $scopeCode = $this->storeManager->getStore()->getCode();
        }

        return (bool) $this->scopeConfig->getValue(self::PATH_ENABLED, $scopeType, $scopeCode);
    }

    /**
     * @inheritDoc
     */
    public function getDefaultDisplay($scopeType = null, $scopeCode = null): int
    {
        if ($scopeType === null) {
            $scopeType = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        }

        if ($scopeCode === null) {
            $scopeCode = $this->storeManager->getStore()->getCode();
        }

        return (int) $this->scopeConfig->getValue(self::PATH_DEFAULT_DISPLAY);
    }
}
