<?php

declare(strict_types=1);

namespace Pinpoint\TaxSwitch\Plugin\Magento\Framework\Pricing;

use Magento\Framework\Pricing\Render;
use Magento\Framework\Pricing\SaleableInterface;
use Pinpoint\TaxSwitch\Api\ConfigHelperInterface;
use Pinpoint\TaxSwitch\Model\Catalog\Pricing\Price\TaxSwitchFinalPrice;

/**
 * This class is responsible for intercepting methods in \Magento\Framework\Pricing\Render
 */
class RenderPlugin
{
    /**
     * @var string
     */
    protected const PRICE_CODE = TaxSwitchFinalPrice::PRICE_CODE;

    /**
     * @var \Pinpoint\TaxSwitch\Api\ConfigHelperInterface
     */
    private $configHelper;

    /**
     * @param \Pinpoint\TaxSwitch\Api\ConfigHelperInterface $configHelper
     */
    public function __construct(ConfigHelperInterface $configHelper)
    {
        $this->configHelper = $configHelper;
    }

    /**
     * @param \Magento\Framework\Pricing\Render            $subject
     * @param string                                       $priceCode
     * @param \Magento\Framework\Pricing\SaleableInterface $item
     * @param array                                        $arguments
     *
     * @return array
     */
    public function beforeRender(
        Render $subject,
        string $priceCode,
        SaleableInterface $item,
        array $arguments = []
    ) {
        if ($this->configHelper->isEnabled()) {
            $priceCode = self::PRICE_CODE;
        }

        return [$priceCode, $item, $arguments];
    }
}
